@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2017 Hive Solutions Lda.
+# Copyright (c) 2008-2018 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -49,6 +49,7 @@ configurations = (
             "php",
             "cs",
             "java",
+            "kt",
             "cpp",
             "c",
             "m",
@@ -69,6 +70,7 @@ configurations = (
             "wik",
             "prl",
             "json",
+            "yml",
             "txt",
             "hxml",
             "hx",
@@ -86,7 +88,9 @@ configurations = (
             "go",
             "md",
             "swift",
-            "Dockerfile"
+            "Dockerfile",
+            "vue",
+            "gradle"
         ),
         "file_exclusion" : ("android-sdk",)
     },
