@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Hive Administration Scripts
-# Copyright (c) 2008-2017 Hive Solutions Lda.
+# Copyright (c) 2008-2018 Hive Solutions Lda.
 #
 # This file is part of Hive Administration Scripts.
 #
@@ -31,7 +31,7 @@ __revision__ = "$LastChangedRevision$"
 __date__ = "$LastChangedDate$"
 """ The last change date of the module """
 
-__copyright__ = "Copyright (c) 2008-2017 Hive Solutions Lda."
+__copyright__ = "Copyright (c) 2008-2018 Hive Solutions Lda."
 """ The copyright for the module """
 
 __license__ = "Apache License, Version 2.0"
@@ -43,6 +43,7 @@ configurations = (
         "windows_newline" : True,
         "fix_extra_newlines" : True,
         "property_order" : (
+            "align-items",
             "animation",
             "-o-animation",
             "-ms-animation",
@@ -61,6 +62,12 @@ configurations = (
             "-moz-animation-duration",
             "-khtml-animation-duration",
             "-webkit-animation-duration",
+            "animation-fill-mode",
+            "-o-animation-fill-mode",
+            "-ms-animation-fill-mode",
+            "-moz-animation-fill-mode",
+            "-khtml-animation-fill-mode",
+            "-webkit-animation-fill-mode",
             "animation-name",
             "-o-animation-name",
             "-ms-animation-name",
@@ -215,6 +222,11 @@ configurations = (
             "font-variant",
             "font-weight",
             "font",
+            "flex",
+            "flex-basis",
+            "flex-direction",
+            "flex-grow",
+            "flex-shrink",
             "height",
             "hyphens",
             "-o-hyphens",
@@ -222,6 +234,8 @@ configurations = (
             "-moz-hyphens",
             "-khtml-hyphens",
             "-webkit-hyphens",
+            "image-rendering",
+            "justify-content",
             "left",
             "letter-spacing",
             "line-height",
@@ -245,6 +259,7 @@ configurations = (
             "-moz-opacity",
             "-khtml-opacity",
             "-webkit-opacity",
+            "order",
             "orphans",
             "osx-font-smoothing",
             "-o-osx-font-smoothing",
@@ -269,6 +284,7 @@ configurations = (
             "-moz-overflow-scrolling",
             "-khtml-overflow-scrolling",
             "-webkit-overflow-scrolling",
+            "overflow-wrap",
             "overflow-x",
             "overflow-y",
             "padding-bottom",
@@ -303,6 +319,7 @@ configurations = (
             "resize",
             "richness",
             "right",
+            "scroll-behavior",
             "size",
             "speak",
             "speak-header",
@@ -346,6 +363,7 @@ configurations = (
             "-webkit-text-shadow",
             "text-transform",
             "top",
+            "touch-action",
             "touch-callout",
             "-o-touch-callout",
             "-ms-touch-callout",
@@ -401,6 +419,8 @@ configurations = (
             "-khtml-transition-timing-function",
             "-webkit-transition-timing-function",
             "unicode-bidi",
+            "user-drag",
+            "-webkit-user-drag",
             "user-select",
             "-o-user-select",
             "-ms-user-select",
