@@ -50,6 +50,7 @@ configurations = (
             "php",
             "cs",
             "java",
+            "kt",
             "css",
             "cpp",
             "c",
@@ -72,6 +73,7 @@ configurations = (
             "wik",
             "prl",
             "json",
+            "yml",
             "txt",
             "hxml",
             "hx",
@@ -91,7 +93,9 @@ configurations = (
             "go",
             "gitignore",
             "swift",
-            "Dockerfile"
+            "Dockerfile",
+            "vue",
+            "gradle"
         ),
         "file_exclusion" : ("android-sdk",)
     },
